@@ -170,7 +170,7 @@ int main(int argc, char **argv)
                          i18n("KDE Wallet Service"),
                          KAboutLicense::LGPL,
                          i18n("(C) 2002-2013, The KDE Developers"));
-    aboutdata.addAuthor(i18n("Valentin Rusu"), i18n("Maintainer, GPG backend support"), QStringLiteral("kde@rusu.info"));
+    aboutdata.addAuthor(i18n("Valentin Rusu"), i18n("Former Maintainer, GPG backend support"), QStringLiteral("kde@rusu.info"));
     aboutdata.addAuthor(i18n("Michael Leupold"), i18n("Former Maintainer"), QStringLiteral("lemma@confuego.org"));
     aboutdata.addAuthor(i18n("George Staikos"), i18n("Former maintainer"), QStringLiteral("staikos@kde.org"));
     aboutdata.addAuthor(i18n("Thiago Maceira"), i18n("D-Bus Interface"), QStringLiteral("thiago@kde.org"));
@@ -202,7 +202,7 @@ int main(int argc, char **argv)
     }
 
     KWalletD walletd;
-    qCDebug(KWALLETD_LOG) << "kwalletd5 started";
+    qCDebug(KWALLETD_LOG) << "kwalletd6 started";
 
 #ifndef Q_OS_WIN
     if (hash) {
